<?php

namespace Models;

require_once '../../models/Model.php';
use Models\Model;
use Controller\Connection;
use PDO;

class Video extends Model
{
    protected $title;
    protected $url;
    protected $tags;
    protected $thumbnail;

    public function __construct($title, $url, $tags, $thumbnail)
    {
        $this->title = self::escapeData($title);
        $this->url = self::escapeData($url);
        $this->tags = self::escapeData($tags);
        $this->thumbnail = self::escapeData($thumbnail);
    }

    public function save(Connection $connection)
    {
        $con = $connection->get_connection();
        $stmt = $con->prepare("INSERT INTO videos (title, url, tags, thumbnail) 
            VALUES (:title, :url, :tags, :thumbnail)");

        $stmt->bindParam(":title", $this->title);
        $stmt->bindParam(":url", $this->url);
        $stmt->bindParam(":tags", $this->tags);
        $stmt->bindParam(":thumbnail", $this->thumbnail);

        return $stmt->execute();
    }

    public static function validate($title, $tags, $file, $thumbnail)
    {
        if($title == null || $tags == null || $file == null || $thumbnail == null)
        {
            return false;
        }
        return true;
    }

    public function saveThumbnail($fileType, $size, $tempName, $name)
    {
        if($fileType == "jpg" || $fileType == "png" || $size < 500000000)
        {
            move_uploaded_file($tempName, $_SERVER["DOCUMENT_ROOT"]."/pruebas-php/public/uploads/".$name);
            return true;
        }
        return false;
    }

    public function saveFile($fileType, $size, $tempName, $name)
    {
        if($fileType == "mp4" || $fileType == "avi" || $size < 500000000)
        {
            move_uploaded_file($tempName, $_SERVER["DOCUMENT_ROOT"]."/pruebas-php/public/uploads/".$name);
            return true;
        }
        return false;
    }

    public static function find(Connection $connection, $id)
    {
        $con = $connection->get_connection();
        $stmt = $con->prepare("SELECT * FROM videos WHERE id=?");
        $stmt->execute(array($id));
        return $stmt->fetch();
    }

    public static function deleteVideo(Connection $connection, $id)
    {
        $con = $connection->get_connection();
        $stmt = $con->prepare("DELETE FROM videos WHERE ID=".$id);
        return $stmt->execute();
    }

    public static function getVideos(Connection $connection)
    {
        $con = $connection->get_connection();
        $stmt = $con->prepare("SELECT * FROM VIDEOS ORDER BY ID DESC LIMIT 3");
        $stmt->execute();
        return $stmt->fetch(PDO::FETCH_ASSOC);

        /*
         * SELECT g.group_id, COUNT(m.member_id) AS members
            FROM groups AS g
            LEFT JOIN group_members AS m USING(group_id)
            GROUP BY g.group_id
            HAVING members > 4
         *
         */
    }
}